==> blanco.plugin.charactergroup_0.1.8-src.zip: blancoCharacterGroupPlugin/blanco/main/blanco/plugin/charactergroup/wizards/AbstractBlancoCharacterGroupWizardPage99.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
package blanco.plugin.charactergroup.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.plugin.charactergroup.BlancoCharacterGroupPluginConstants;

/**
 */
public abstract class AbstractBlancoCharacterGroupWizardPage99 extends WizardPage {
    /**
     */
    private ISelection selection;

    /**
     *
     * @param selection
     */
    public AbstractBlancoCharacterGroupWizardPage99(final ISelection selection) {
        super("wizardPage");
        setTitle("blancoCharacterGroupvOCpxEBU[h̊");
        this.selection = selection;
    }

    /**
     *
     * @param parent
     */
    public void createControl(final Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE).setText("blancoCharacterGroupvOCpxEBU[h Ŋ܂B");
        new Label(container, SWT.NONE).setText("  1.EBU[h ublancoCharacterGroupݒt@C GfB^v\܂B");
        new Label(container, SWT.NONE).setText("    ̉ʂ " + BlancoCharacterGroupPluginConstants.TARGET_FILENAME + "t@C̃GfB^vOɑ܂B");
        new Label(container, SWT.NONE).setText("  2.ʕ\ɏ]đi߂ĂB");

        setControl(container);
    }
}

==> blanco.plugin.charactergroup_0.2.1-src.zip: blancoCharacterGroupPlugin/blanco/main/blanco/plugin/charactergroup/wizards/AbstractBlancoCharacterGroupWizardPage99.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
package blanco.plugin.charactergroup.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.plugin.charactergroup.BlancoCharacterGroupPluginConstants;

/**
 */
public abstract class AbstractBlancoCharacterGroupWizardPage99 extends WizardPage {
    /**
     */
    protected ISelection selection;

    /**
     *
     * @param selection
     */
    public AbstractBlancoCharacterGroupWizardPage99(final ISelection selection) {
        super("wizardPage");
        setTitle("blancoCharacterGroupvOCpxEBU[h̊");
        this.selection = selection;
    }

    /**
     *
     * @param parent
     */
    public void createControl(final Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE).setText("blancoCharacterGroupvOCpxEBU[h Ŋ܂B");
        new Label(container, SWT.NONE).setText("  1.EBU[h ublancoCharacterGroupݒt@C GfB^v\܂B");
        new Label(container, SWT.NONE).setText("    ̉ʂ " + BlancoCharacterGroupPluginConstants.TARGET_FILENAME + "t@C̃GfB^vOɑ܂B");
        new Label(container, SWT.NONE).setText("  2.ʕ\ɏ]đi߂ĂB");

        setControl(container);
    }
}
